@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.1300';
+our $VERSION = '0.1301';
 
 use strict;
 use warnings;
@@ -300,7 +300,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.1300
+version 0.1301
 
 =head1 SYNOPSIS
 
@@ -315,6 +315,8 @@ version 0.1300
     ticks
     timidity_conf
     play_timidity
+    get_milliseconds
+    score2events
   );
 
   my $dump = midi_dump('length'); # volume, etc.
@@ -343,6 +345,10 @@ version 0.1300
   # Or you can just play the score:
   play_timidity($score, 'some.mid');
 
+  my $ms = get_milliseconds($score);
+
+  my $events = score2events($score);
+
 =head1 DESCRIPTION
 
 C<MIDI::Util> comprises handy MIDI utilities.
@@ -354,7 +360,6 @@ Nothing is exported by default.
 =head2 setup_score
 
   $score = setup_score;  # Use defaults
-
   $score = setup_score(  # Override defaults
     lead_in   => $beats,
     volume    => $volume,
@@ -382,7 +387,6 @@ Named parameters and defaults:
 =head2 set_chan_patch
 
   set_chan_patch( $score, $channel );  # Just set the channel
-
   set_chan_patch( $score, $channel, $patch );
 
 Set the MIDI channel and patch.
@@ -463,9 +467,9 @@ Return the B<score> ticks.
   $timidity_conf = timidity_conf($soundfont);
   timidity_conf($soundfont, $config_file);
 
-A suggested timidity.cfg paragraph to allow you to use this soundfont
-in timidity. If a B<config_file> is given, the timidity configuration
-is written to that file.
+A suggested timidity.cfg paragraph to allow you to use the given
+soundfont in timidity. If a B<config_file> is given, the timidity
+configuration is written to that file.
 
 =head2 play_timidity
 
@@ -490,16 +494,18 @@ ticks.
 
   score2events($score_obj);
 
-Return the B<score> as a series of events.
+Return the B<score> as array reference of events.
 
 =head1 SEE ALSO
 
-The F<t/01-functions.t> test file and F<eg/*> in this distribution
+The F<t/01-functions.t> test file and F<eg/*> examples in this distribution.
 
 L<Exporter>
 
 L<File::Slurper>
 
+L<List::Util>
+
 L<MIDI>
 
 L<MIDI::Simple>
